<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit( 0 );
}

/**
 * Module to handle BuddyBoss specific tab visibility
 *
 * BB Tabs Helper
 */
class BP_Profile_Visibility_BB_Tabs_Helper {

	/**
	 * Singleton.
	 *
	 * @var BP_Profile_Visibility_BB_Tabs_Helper
	 */
	private static $instance = null;

	/**
	 * Constructor.
	 */
	private function __construct() {
		$this->setup();
	}

	/**
	 * Get singleton.
	 *
	 * @return BP_Profile_Visibility_BB_Tabs_Helper
	 */
	public static function get_instance() {

		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Setup hiding of BuddyBoss specific nav.
	 */
	private function setup() {
		$manager = bp_profile_visibility_manager();

		if ( $manager->get_option( 'enable_bb_photo_tab_visibility' ) === 'yes' ) {
			add_action( 'bp_media_setup_nav', array( $this, 'hide_photo_nav' ) );
		}

		if ( $manager->get_option( 'enable_bb_video_tab_visibility' ) === 'yes' ) {
			add_action( 'bp_video_setup_nav', array( $this, 'hide_video_nav' ) );
		}

		if ( $manager->get_option( 'enable_bb_document_tab_visibility' ) === 'yes' ) {
			add_action( 'bp_document_setup_nav', array( $this, 'hide_document_nav' ) );
		}

		if ( $manager->get_option( 'enable_bb_forum_tab_visibility' ) === 'yes' ) {
			add_action( 'bp_forums_setup_nav', array( $this, 'hide_forum_nav' ) );
		}
	}

	/**
	 * Hide photo nav if needed.
	 */
	public function hide_photo_nav() {

		// do not hide if not on a user profile or his/her own profile or the user is super admin.
		if ( ! bp_is_user() || bp_is_my_profile() || bp_profile_visibility_is_admin_user() ) {
			return;
		}

		$displayed_user_id = bp_displayed_user_id();

		$privacy = bp_profile_visibility_get_settings( $displayed_user_id, 'bp_profile_bb_photo_tab_visibility' );

		if ( ! $this->hide_nav( $privacy, $displayed_user_id ) ) {
			return;
		}

		bp_core_remove_nav_item( 'photos' );
	}

	/**
	 * Hide video nav if needed.
	 */
	public function hide_video_nav() {

		// do not hide if not on a user profile or his/her own profile or the user is super admin.
		if ( ! bp_is_user() || bp_is_my_profile() || bp_profile_visibility_is_admin_user() ) {
			return;
		}

		$displayed_user_id = bp_displayed_user_id();

		$privacy = bp_profile_visibility_get_settings( $displayed_user_id, 'bp_profile_bb_video_tab_visibility' );

		if ( ! $this->hide_nav( $privacy, $displayed_user_id ) ) {
			return;
		}

		bp_core_remove_nav_item( 'videos' );
	}

	/**
	 * Hide document nav if needed.
	 */
	public function hide_document_nav() {

		// do not hide if not on a user profile or is own profile or the user is super admin.
		if ( ! bp_is_user() || bp_is_my_profile() || bp_profile_visibility_is_admin_user() ) {
			return;
		}

		$displayed_user_id = bp_displayed_user_id();

		$privacy = bp_profile_visibility_get_settings( $displayed_user_id, 'bp_profile_bb_document_tab_visibility' );

		if ( ! $this->hide_nav( $privacy, $displayed_user_id ) ) {
			return;
		}

		bp_core_remove_nav_item( 'documents' );
	}

	/**
	 * Hide forum nav if needed.
	 */
	public function hide_forum_nav() {

		// do not hide if not on a user profile or his/her own profile or the user is super admin.
		if ( ! bp_is_user() || bp_is_my_profile() || bp_profile_visibility_is_admin_user() ) {
			return;
		}

		$displayed_user_id = bp_displayed_user_id();

		$privacy = bp_profile_visibility_get_settings( $displayed_user_id, 'bp_profile_bb_forum_tab_visibility' );

		if ( ! $this->hide_nav( $privacy, $displayed_user_id ) ) {
			return;
		}

		bp_core_remove_nav_item( 'forums' );
	}

	/**
	 * Checks current user meets privacy.
	 *
	 * @param string $privacy           Privacy as per setting.
	 * @param int    $displayed_user_id Displayed user id.
	 *
	 * @return bool
	 */
	private function hide_nav( $privacy, $displayed_user_id ) {
		$logged_user_id = bp_loggedin_user_id();

		$hide = true;
		if ( empty( $privacy ) || $privacy === 'public' ) {
			$hide = false;
		} elseif ( $privacy === 'loggedin' && is_user_logged_in() ) {
			$hide = false;
		} elseif ( 'friends' === $privacy && function_exists( 'friends_check_friendship' ) && friends_check_friendship( $logged_user_id, $displayed_user_id ) ) {
			$hide = false;
		} elseif ( 'groups' === $privacy && bp_profile_visibility_has_common_group( $logged_user_id, $displayed_user_id ) ) {
			$hide = false;
		}

		return $hide;
	}
}

BP_Profile_Visibility_BB_Tabs_Helper::get_instance();
